Contributing
============

Testing locally
---------------

1. `git clone` this repo
    - `git clone https://github.com/AMYPAD/SPM12`
    - `cd SPM12`
2. install developer dependencies
    - `pip install -U .[dev]`
3. run tests
    - `python -m tests`

You will likely get an error message detailing where to download test data.
